@@ -38,9 +38,7 @@ open Modules
 open Frontend
 
 let eval x =
-  Query.eval_source
-    (Package.of_assoc Source Core.StringMap.empty)
-    (Query.of_expr x)
+  Query.eval_source (Package.of_stanza Source Stanza.empty) (Query.of_expr x)
 
 let read_global_config file =
   if Sys.file_exists file then
